@@ -18,7 +18,7 @@ from tiddlyweb.util import sha
 from tiddlywebplugins.utils import get_store
 
 
-__version__ = "0.7.14"
+__version__ = "0.7.15"
 
 CONFIG_NAME = "tiddlywebconfig.py"
 
@@ -66,7 +66,7 @@ class Instance(object):
         store = get_store(self.init_config)
         for bag, uris in self.init_config["instance_tiddlers"].items():
             for tiddler in sourcer.from_list(uris):
-                tiddler.bag = bag
+                tiddler.bag = unicode(bag)
                 store.put(tiddler)
 
     def _init_store(self, struct):
